==> automated_testing_framework-0.2.3.tar.gz: lib/src/translations/test_translations.dart <==
import 'package:static_translations/static_translations.dart';

class TestTranslations {
  TestTranslations._();

  static final atf_added_step_action = TranslationEntry(
    key: 'atf_added_step_action',
    value: 'Added Step: {step}',
  );

  static final atf_available_test_steps = TranslationEntry(
    key: 'atf_available_test_steps',
    value: 'Available Test Steps',
  );

  static final atf_button_cancel = TranslationEntry(
    key: 'atf_button_cancel',
    value: 'CANCEL',
  );

  static final atf_button_discard = TranslationEntry(
    key: 'atf_button_discard',
    value: 'DISCARD',
  );

  static final atf_button_delete = TranslationEntry(
    key: 'atf_button_delete',
    value: 'DELETE',
  );

  static final atf_button_clear = TranslationEntry(
    key: 'atf_button_clear',
    value: 'CLEAR',
  );

  static final atf_button_close = TranslationEntry(
    key: 'atf_button_close',
    value: 'CLOSE',
  );

  static final atf_button_edit = TranslationEntry(
    key: 'atf_button_edit',
    value: 'EDIT',
  );

  static final atf_button_export = TranslationEntry(
    key: 'atf_button_export',
    value: 'EXPORT',
  );

  static final atf_button_ok = TranslationEntry(
    key: 'atf_button_ok',
    value: 'OK',
  );

  static final atf_button_rerun = TranslationEntry(
    key: 'atf_button_rerun',
    value: 'RUN TEST AGAIN',
  );

  static final atf_button_run = TranslationEntry(
    key: 'atf_button_run',
    value: 'RUN',
  );

  static final atf_button_run_all = TranslationEntry(
    key: 'atf_button_run_all',
    value: 'RUN ALL',
  );

  static final atf_button_submit = TranslationEntry(
    key: 'atf_button_submit',
    value: 'SUBMIT',
  );

  static const atf_button_view_steps = TranslationEntry(
    key: 'atf_button_view_steps',
    value: 'VIEW STEPS',
  );

  static const atf_button_view_test_steps = TranslationEntry(
    key: 'atf_button_view_test_steps',
    value: 'VIEW TEST STEPS ({count})',
  );

  static const atf_clear_confirmation = TranslationEntry(
    key: 'atf_clear_confirmation',
    value: 'Are you sure you want to clear all the test steps?',
  );

  static final atf_copied_to_clipboard = TranslationEntry(
    key: 'atf_copied_to_clipboard',
    value: 'Copied to clipboard',
  );

  static const atf_correct_errors = TranslationEntry(
    key: 'atf_correct_errors',
    value: 'Please correct form errors before continuing.',
  );

  static const atf_discard_changes = TranslationEntry(
    key: 'atf_discard_changes',
    value: 'Discard changes?',
  );

  static const atf_export_successful = TranslationEntry(
    key: 'atf_export_successful',
    value: 'Export successful',
  );

  static final atf_no_tests_found = TranslationEntry(
    key: 'atf_no_tests_found',
    value: 'No tests found',
  );

  static final atf_operation_not_supported = TranslationEntry(
    key: 'atf_operation_not_supported',
    value: 'Operation not supported',
  );

  static final atf_options = TranslationEntry(
    key: 'atf_options',
    value: 'Options',
  );

  static final atf_quick_add = TranslationEntry(
    key: 'atf_quick_add',
    value: 'Quick Add Step',
  );

  static final atf_selected_widget_steps = TranslationEntry(
    key: 'atf_selected_widget_steps',
    value: 'Selected Widget Steps',
  );

  static final atf_show_global_overlays = TranslationEntry(
    key: 'atf_show_global_overlays',
    value: 'Show global overlays',
  );

  static final atf_test_name = TranslationEntry(
    key: 'atf_test_name',
    value: 'Test Name',
  );

  static const atf_test_options = TranslationEntry(
    key: 'qa_test_options',
    value: 'Test Options',
  );

  static final atf_tests = TranslationEntry(
    key: 'atf_tests',
    value: 'Tests',
  );

  static final atf_timeout_seconds = TranslationEntry(
    key: 'atf_timeout_seconds',
    value: 'Timeout (seconds)',
  );

  static final atf_tooltip_add_and_run = TranslationEntry(
    key: 'atf_tooltip_add_and_run',
    value: 'Add step and immediately execute',
  );

  static final atf_unnamed_test = TranslationEntry(
    key: 'atf_unnamed_test',
    value: '<Unnamed Test>',
  );

  static final atf_version_steps = TranslationEntry(
    key: 'atf_version_steps',
    value: 'Version: {version} / Steps: {steps}',
  );

  static final atf_widget = TranslationEntry(
    key: 'atf_widget',
    value: 'Widget',
  );

  static final atf_widgetless_steps = TranslationEntry(
    key: 'atf_widgetless_steps',
    value: 'Other Steps',
  );
}

==> automated_testing_framework-1.0.0.tar.gz: lib/src/translations/test_translations.dart <==
import 'package:static_translations/static_translations.dart';

class TestTranslations {
  TestTranslations._();

  static final atf_added_step_action = TranslationEntry(
    key: 'atf_added_step_action',
    value: 'Added Step: {step}',
  );

  static final atf_available_test_steps = TranslationEntry(
    key: 'atf_available_test_steps',
    value: 'Available Test Steps',
  );

  static final atf_button_cancel = TranslationEntry(
    key: 'atf_button_cancel',
    value: 'CANCEL',
  );

  static final atf_button_discard = TranslationEntry(
    key: 'atf_button_discard',
    value: 'DISCARD',
  );

  static final atf_button_delete = TranslationEntry(
    key: 'atf_button_delete',
    value: 'DELETE',
  );

  static final atf_button_clear = TranslationEntry(
    key: 'atf_button_clear',
    value: 'CLEAR',
  );

  static final atf_button_close = TranslationEntry(
    key: 'atf_button_close',
    value: 'CLOSE',
  );

  static final atf_button_edit = TranslationEntry(
    key: 'atf_button_edit',
    value: 'EDIT',
  );

  static final atf_button_export = TranslationEntry(
    key: 'atf_button_export',
    value: 'EXPORT',
  );

  static final atf_button_ok = TranslationEntry(
    key: 'atf_button_ok',
    value: 'OK',
  );

  static final atf_button_rerun = TranslationEntry(
    key: 'atf_button_rerun',
    value: 'RUN TEST AGAIN',
  );

  static final atf_button_run = TranslationEntry(
    key: 'atf_button_run',
    value: 'RUN',
  );

  static final atf_button_run_all = TranslationEntry(
    key: 'atf_button_run_all',
    value: 'RUN ALL',
  );

  static final atf_button_submit = TranslationEntry(
    key: 'atf_button_submit',
    value: 'SUBMIT',
  );

  static const atf_button_view_steps = TranslationEntry(
    key: 'atf_button_view_steps',
    value: 'VIEW STEPS',
  );

  static const atf_button_view_test_steps = TranslationEntry(
    key: 'atf_button_view_test_steps',
    value: 'VIEW TEST STEPS ({count})',
  );

  static const atf_clear_confirmation = TranslationEntry(
    key: 'atf_clear_confirmation',
    value: 'Are you sure you want to clear all the test steps?',
  );

  static final atf_copied_to_clipboard = TranslationEntry(
    key: 'atf_copied_to_clipboard',
    value: 'Copied to clipboard',
  );

  static const atf_correct_errors = TranslationEntry(
    key: 'atf_correct_errors',
    value: 'Please correct form errors before continuing.',
  );

  static const atf_discard_changes = TranslationEntry(
    key: 'atf_discard_changes',
    value: 'Discard changes?',
  );

  static const atf_export_successful = TranslationEntry(
    key: 'atf_export_successful',
    value: 'Export successful',
  );

  static final atf_maximize_step_details = TranslationEntry(
    key: 'atf_maximize_step_details',
    value: 'Show full step details',
  );

  static final atf_minimize_step_details = TranslationEntry(
    key: 'atf_minimize_step_details',
    value: 'Show minimal step details',
  );

  static final atf_no_tests_found = TranslationEntry(
    key: 'atf_no_tests_found',
    value: 'No tests found',
  );

  static final atf_operation_not_supported = TranslationEntry(
    key: 'atf_operation_not_supported',
    value: 'Operation not supported',
  );

  static final atf_options = TranslationEntry(
    key: 'atf_options',
    value: 'Options',
  );

  static final atf_quick_add = TranslationEntry(
    key: 'atf_quick_add',
    value: 'Quick Add Step',
  );

  static final atf_selected_widget_steps = TranslationEntry(
    key: 'atf_selected_widget_steps',
    value: 'Selected Widget Steps',
  );

  static final atf_show_global_overlays = TranslationEntry(
    key: 'atf_show_global_overlays',
    value: 'Show global overlays',
  );

  static final atf_test_name = TranslationEntry(
    key: 'atf_test_name',
    value: 'Test Name',
  );

  static const atf_test_options = TranslationEntry(
    key: 'atf_test_options',
    value: 'Test Options',
  );

  static const atf_test_steps = TranslationEntry(
    key: 'atf_test_steps',
    value: 'Test Steps',
  );

  static const atf_test_suite_results = TranslationEntry(
    key: 'atf_test_suite_results',
    value: 'Test Suite Results',
  );

  static final atf_tests = TranslationEntry(
    key: 'atf_tests',
    value: 'Tests',
  );

  static final atf_timeout_seconds = TranslationEntry(
    key: 'atf_timeout_seconds',
    value: 'Timeout (seconds)',
  );

  static final atf_tooltip_add_and_run = TranslationEntry(
    key: 'atf_tooltip_add_and_run',
    value: 'Add step and immediately execute',
  );

  static final atf_unnamed_test = TranslationEntry(
    key: 'atf_unnamed_test',
    value: '<Unnamed Test>',
  );

  static final atf_version_steps = TranslationEntry(
    key: 'atf_version_steps',
    value: 'Version: {version} / Steps: {steps}',
  );

  static final atf_widget = TranslationEntry(
    key: 'atf_widget',
    value: 'Widget',
  );

  static final atf_widgetless_steps = TranslationEntry(
    key: 'atf_widgetless_steps',
    value: 'Other Steps',
  );
}
